@@ -27,15 +27,15 @@ class ImportCommand:
         return None
 
     @classmethod
-    def run(cls, background: bool = False):
+    def run(cls, background: bool = False, version: Optional[int] = None):
         """Run the import command (foreground/background)."""
         if background:
             from .tasks import TASKS
 
             task = TASKS[cls.task_name]
-            task.delay()
+            task.delay(version=version)
         else:
-            _untis_import_mysql(cls.get_terms())
+            _untis_import_mysql(cls.get_terms(), version=version)
 
 
 class CurrentImportCommand(ImportCommand):
