@@ -13,8 +13,13 @@ class Command(BaseCommand):
             action="store_true",
             help="Run import job in background using Celery",
         )
+        parser.add_argument(
+            "--plan-version",
+            help="Select explicit Untis plan version",
+        )
 
     def handle(self, *args, **options):
         command = COMMANDS_BY_NAME[options["command"]]
         background = options["background"]
-        command.run(background=background)
+        version = options.get("plan_version", None)
+        command.run(background=background, version=version)
