@@ -89,3 +89,11 @@ class UseCourseGroups(BooleanPreference):
     help_text = _(
         "Build or search course groups for every course" " instead of setting classes as groups."
     )
+
+
+@site_preferences_registry.register
+class IgnoreIncompleteSubstitutions(BooleanPreference):
+    section = untis_mysql
+    name = "ignore_incomplete_substitutions"
+    default = True
+    verbose_name = _("Ignore incomplete substitutions")
