@@ -126,7 +126,8 @@ def import_lessons(
 
                 # Search by parent groups and subject
                 qs = core_models.Group.objects.filter(
-                    parent_groups__in=[c.id for c in course_classes], subject_id=subject.id,
+                    parent_groups__in=[c.id for c in course_classes],
+                    subject_id=subject.id,
                 ).filter(Q(school_term__isnull=True) | Q(school_term=validity_range.school_term))
 
                 # Check if found groups match
@@ -145,10 +146,12 @@ def import_lessons(
 
                     # Build names and refs for course groups
                     group_short_name = "{}-{}".format(
-                        "".join([c.short_name for c in course_classes]), subject.short_name,
+                        "".join([c.short_name for c in course_classes]),
+                        subject.short_name,
                     )
                     group_name = "{}: {}".format(
-                        ", ".join([c.short_name for c in course_classes]), subject.short_name,
+                        ", ".join([c.short_name for c in course_classes]),
+                        subject.short_name,
                     )
 
                     # Get or create course group
@@ -274,6 +277,6 @@ def import_lessons(
         if lesson.lesson_id_untis and lesson.lesson_id_untis not in existing_lessons:
             logger.info("Lesson {} deleted".format(lesson.id))
             with reversion.create_revision():
-                set_comment(_("Deleted by UNTIS import"))
+                set_comment(_("Deleted by Untis import"))
                 lesson.save()
             lesson.delete()
