@@ -25,9 +25,9 @@ from .importers.lessons import import_lessons
 from .importers.substitutions import import_substitutions
 
 
-def untis_import_mysql(terms: Optional[QuerySet] = None):
+def untis_import_mysql(terms: Optional[QuerySet] = None, version: Optional[int] = None):
     # School terms and validity ranges
-    validity_ref = import_terms(terms)
+    validity_ref = import_terms(terms, version=version)
 
     for validity_range in tqdm(
         validity_ref.values(), desc="Import data for terms", **TQDM_DEFAULTS
